@@ -1,6 +1,10 @@
-import base64, json, time
+import base64
+import json
+import time
+
 from .version import __version__
 
+
 def firetail_handler(enable_sleeper=False):
     def decorator(func):
         def wrapper_func(*args, **kwargs):
